@@ -1,6 +1,6 @@
 package Net::HTTP;
 
-# $Id: HTTP.pm,v 1.31 2001/05/05 13:40:34 gisle Exp $
+# $Id: HTTP.pm,v 1.33 2001/08/02 23:30:44 gisle Exp $
 
 require 5.005;  # 4-arg substr
 
@@ -13,22 +13,6 @@ require IO::Socket::INET;
 
 my $CRLF = "\015\012";   # "\r\n" is not portable
 
-my $zlib_ok;
-{
-    # Try to load Compress::Zlib.
-    # It might be a better idea to load this on demand the first time
-    # the 'send_te' option is turned on.
-    local $@;
-    local $SIG{__DIE__};
-
-    eval {
-	require Compress::Zlib;
-	Compress::Zlib->VERSION(1.10);
-	$zlib_ok++;
-    };
-    #warn $@ if $@ && $^W;
-}
-
 sub configure {
     my($self, $cnf) = @_;
 
@@ -152,7 +136,7 @@ sub format_request {
     if ($given{te}) {
 	push(@connection, "TE") unless grep lc($_) eq "te", @connection;
     }
-    elsif ($self->send_te && $zlib_ok) {
+    elsif ($self->send_te && zlib_ok()) {
 	# gzip is less wanted since the Compress::Zlib interface for
 	# it does not really allow chunked decoding to take place easily.
 	push(@h2, "TE: deflate,gzip;q=0.3");
@@ -316,6 +300,7 @@ sub read_response_headers {
     ${*$self}{'http_content_length'} = $content_length;
     ${*$self}{'http_first_body'}++;
     delete ${*$self}{'http_trailers'};
+    return $code unless wantarray;
     return ($code, $message, @headers);
 }
 
@@ -344,13 +329,13 @@ sub read_entity_body {
 		unless pop(@te) eq "chunked";
 
 	    for (@te) {
-		if ($_ eq "deflate" && $zlib_ok) {
+		if ($_ eq "deflate" && zlib_ok()) {
 		    #require Compress::Zlib;
 		    my $i = Compress::Zlib::inflateInit();
 		    die "Can't make inflator" unless $i;
 		    $_ = sub { scalar($i->inflate($_[0])) }
 		}
-		elsif ($_ eq "gzip" && $zlib_ok) {
+		elsif ($_ eq "gzip" && zlib_ok()) {
 		    #require Compress::Zlib;
 		    my @buf;
 		    $_ = sub {
@@ -465,6 +450,29 @@ sub get_trailers {
     @{${*$self}{'http_trailers'} || []};
 }
 
+BEGIN {
+my $zlib_ok;
+
+sub zlib_ok {
+    return $zlib_ok if defined $zlib_ok;
+
+    # Try to load Compress::Zlib.
+    local $@;
+    local $SIG{__DIE__};
+    $zlib_ok = 0;
+
+    eval {
+	require Compress::Zlib;
+	Compress::Zlib->VERSION(1.10);
+	$zlib_ok++;
+    };
+    #warn $@ if $@ && $^W;
+}
+
+} # BEGIN
+
+
+
 1;
 
 __END__
@@ -500,7 +508,8 @@ HTTP protocol is described in RFC 2616.
 
 C<Net::HTTP> is a sub-class of C<IO::Socket::INET>.  You can mix the
 methods described below with reading and writing from the socket
-directly.
+directly.  This is not necessary a good idea, unless you know what you
+are doing.
 
 The following methods are provided (in addition to those of
 C<IO::Socket::INET>):
@@ -535,7 +544,7 @@ and C<peer_http_version> attributes.
 =item $s->send_te
 
 Get/set the a value indicating if the request will be sent with a "TE"
-header to indicate the transfer encodings that the server chose to
+header to indicate the transfer encodings that the server can chose to
 use.  If the C<Compress::Zlib> module is installed then this will
 annouce that this client accept both the I<deflate> and I<gzip>
 encodings.
@@ -595,7 +604,18 @@ Returns the string to be written for signaling EOF.
 
 =item ($code, $mess, %headers) = $s->read_response_headers
 
-Read response headers from server.
+Read response headers from server.  The $code is the 3 digit HTTP
+status code (see L<HTTP::Status>) and $mess is the textual message
+that came with it.  Headers are then returned as key/value pairs.
+Since key letter casing is not normalized and the same key can occur
+multiple times, assigning these values directly to a hash might be
+risky.
+
+As a side effect this method updates the 'peer_http_version'
+attribute.
+
+The method will raise exceptions (die) if the server does not speak
+proper HTTP.
 
 =item $n = $s->read_entity_body($buf, $size);
 
@@ -608,6 +628,9 @@ The return value will be C<undef> on errors, 0 on EOF, -1 if no data
 could be returned this time, and otherwise the number of bytes added
 to $buf.
 
+This method might raise exceptions (die) if the server does not speak
+proper HTTP.
+
 =item %headers = $s->get_trailers
 
 After read_entity_body() has returned 0 to indicate end of the entity
